@@ -15,11 +15,11 @@ Ixchel - Automate various sys admin stuff.
 
 =head1 VERSION
 
-Version 0.3.0
+Version 0.4.0
 
 =cut
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.4.0';
 
 =head1 METHODS
 
@@ -141,6 +141,16 @@ Now if we want to pass '--np' to not print it, we would do it like below.
 
     my $rendered_template=$ixchel->action( action=>'template', opts=>{ t=>'extend_logsize', np=>1 });
 
+If the following values are defined, the matching ENV is set.
+
+    .proxy.ftp       ->  FTP_PROXY
+    .proxy.http      ->  HTTP_PROXY
+    .proxy.https     ->  HTTPS_PROXY
+    .perl.cpanm_home ->  PERL_CPANM_HOME
+
+Additionally any of the variables defined under .env will also be
+set. So .env.TMPDIR will set $ENV{TMPDIR}.
+
 =cut
 
 sub action {
@@ -188,6 +198,26 @@ sub action {
 		$vars = $opts{vars};
 	}
 
+	# set the enviromental variables if needed
+	if ( defined( $self->{config}{proxy}{ftp} ) && $self->{config}{proxy}{ftp} ne '' ) {
+		$ENV{FTP_PROXY} = $self->{config}{proxy}{ftp};
+	}
+	if ( defined( $self->{config}{proxy}{http} ) && $self->{config}{proxy}{http} ne '' ) {
+		$ENV{HTTP_PROXY} = $self->{config}{proxy}{http};
+	}
+	if ( defined( $self->{config}{proxy}{https} ) && $self->{config}{proxy}{https} ne '' ) {
+		$ENV{HTTPS_PROXY} = $self->{config}{proxy}{https};
+	}
+	if ( defined( $self->{config}{perl}{cpanm_home} ) && $self->{config}{perl}{cpanm_home} ne '' ) {
+		$ENV{PERL_CPANM_HOME} = $self->{config}{perl}{cpanm_home};
+	}
+	my @env_keys = keys( %{ $self->{config}{env} } );
+	foreach my $env_key (@env_keys) {
+		if ( defined( $self->{config}{env}{$env_key} ) && ref( $self->{config}{env}{$env_key} ) eq '' ) {
+			$ENV{$env_key} = $self->{config}{env}{$env_key};
+		}
+	}
+
 	my $action_return;
 	my $action_obj;
 	my $to_eval
